# Contributing

## How to get help or discuss possible contributions

To avoid duplicating issues, please search our [issue tracker][issues] before
filing a new issue.

- Open an [issue][new_issue] describing your problem.

## How to make a contribution

- Fork the [benchmark-tool][project_url] repository and create a branch for
  your changes.
- Submit a pull request to the master branch with your changes.
- Respond to feedback on your pull request.
- If everything is fine your pull request is merged. 🥳

## License

When contributing to this project, you agree that you have authored 100% of the
content, that you have the necessary rights to the content and that the content
you contribute may be provided under the project license.

[issues]: https://github.com/potassco/benchmark-tool/issues
[new_issue]: https://github.com/potassco/benchmark-tool/issues/new
[project_url]: https://github.com/potassco/benchmark-tool
